
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.24.1.post2',
    'branch_nick': 'hotfix-1.24.1.post2',
    'revision_id': '822aefdd5363b3d31e7ce164bbe7f92ce8437019',
    'revno': 10296
}
